summaryrefslogtreecommitdiffstats
path: root/include/clang/Frontend/ASTConsumers.h
diff options
context:
space:
mode:
authorChandler Carruth <chandlerc@gmail.com>2009-11-12 17:24:48 +0000
committerChandler Carruth <chandlerc@gmail.com>2009-11-12 17:24:48 +0000
commit2811ccf48d6d898c42cc4cfad37abedb36236d20 (patch)
tree283a52cb33efc6e98cb15cacf2ecc63f3707cae7 /include/clang/Frontend/ASTConsumers.h
parent95c5d8ac29ba3423e735a0732713907e484b800d (diff)
Move CompileOptions -> CodeGenOptions, and sink it into the CodeGen library.
This resolves the layering violation where CodeGen depended on Frontend. git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@86998 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include/clang/Frontend/ASTConsumers.h')
-rw-r--r--include/clang/Frontend/ASTConsumers.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/clang/Frontend/ASTConsumers.h b/include/clang/Frontend/ASTConsumers.h
index 742813c669..cd35638f2c 100644
--- a/include/clang/Frontend/ASTConsumers.h
+++ b/include/clang/Frontend/ASTConsumers.h
@@ -28,7 +28,7 @@ class ASTConsumer;
class Diagnostic;
class FileManager;
class Preprocessor;
-class CompileOptions;
+class CodeGenOptions;
class LangOptions;
// AST pretty-printer: prints out the AST in a format that is close to the
@@ -69,7 +69,7 @@ ASTConsumer *CreateObjCRewriter(const std::string &InFile,
bool SilenceRewriteMacroWarning);
// LLVM code generator: uses the code generation backend to generate LLVM
// assembly. This runs optimizations depending on the CompileOptions
// parameter. The output depends on the Action parameter.
enum BackendAction {
Backend_EmitAssembly, // Emit native assembly
@@ -80,7 +80,7 @@ enum BackendAction {
ASTConsumer *CreateBackendConsumer(BackendAction Action,
Diagnostic &Diags,
const LangOptions &Features,
- const CompileOptions &CompileOpts,
+ const CodeGenOptions &CodeGenOpts,
const std::string &ModuleID,
llvm::raw_ostream *OS,
llvm::LLVMContext& C);
@@ -69,7 +69,7 @@ ASTConsumer *CreateObjCRewriter(const std::string &InFile,
bool SilenceRewriteMacroWarning);
// LLVM code generator: uses the code generation backend to generate LLVM
-// assembly. This runs optimizations depending on the CompileOptions
+// assembly. This runs optimizations depending on the CodeGenOptions
// parameter. The output depends on the Action parameter.
enum BackendAction {